==> nowa_runtime-0.0.27.tar.gz: lib/src/widgets/nowa_video_player_controller.dart <==
import 'package:appinio_video_player/appinio_video_player.dart';
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';

class NowaVideoPlayerController {
  NowaVideoPlayerController({
    required this.url,
    this.autoPlay = false,
    this.showControlsBar = true,
    this.allowFullScreenButton = true,
  });

  final String type = 'network';
  final String? url;
  final bool autoPlay;
  final bool showControlsBar;
  final bool allowFullScreenButton;

  late VideoPlayerController _videoPlayerController;
  late CustomVideoPlayerWebSettings _customVideoPlayerWebSettings;
  late CustomVideoPlayerController customVideoPlayerController;
  late CustomVideoPlayerWebController customVideoPlayerWebController;

  Future<bool> initialize(BuildContext context) async {
    if (url == null) return false;

    if (!kIsWeb) {
      if (type == 'asset') {
        _videoPlayerController = VideoPlayerController.asset(url!);
        await _videoPlayerController.initialize();
        if (autoPlay) {
          _videoPlayerController.play();
        }
      } else {
        _videoPlayerController = VideoPlayerController.networkUrl(Uri.parse(url!));
        await _videoPlayerController.initialize();
        if (autoPlay) {
          _videoPlayerController.play();
        }
      }
      customVideoPlayerController = CustomVideoPlayerController(
        context: context,
        videoPlayerController: _videoPlayerController,
        customVideoPlayerSettings: CustomVideoPlayerSettings(
          alwaysShowThumbnailOnVideoPaused: true,
          controlBarAvailable: showControlsBar,
          showFullscreenButton: allowFullScreenButton,
        ),
      );
    }

    _customVideoPlayerWebSettings = CustomVideoPlayerWebSettings(
      src: url!,
      enableControls: showControlsBar,
      autoplay: autoPlay,
    );
    customVideoPlayerWebController = CustomVideoPlayerWebController(
      webVideoPlayerSettings: _customVideoPlayerWebSettings,
    );

    return true;
  }

  void dispose() {
    customVideoPlayerController.dispose();
  }
}

==> nowa_runtime-0.0.31.tar.gz: lib/src/widgets/nowa_video_player_controller.dart <==
import 'package:appinio_video_player/appinio_video_player.dart';
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';

class NowaVideoPlayerController {
  NowaVideoPlayerController({
    required this.url,
    this.autoPlay = false,
    this.showControlsBar = true,
    this.allowFullScreenButton = true,
  });

  final String type = 'network';
  final String? url;
  final bool autoPlay;
  final bool showControlsBar;
  final bool allowFullScreenButton;

  late CachedVideoPlayerController _videoPlayerController;
  late CustomVideoPlayerWebSettings _customVideoPlayerWebSettings;
  late CustomVideoPlayerController customVideoPlayerController;
  late CustomVideoPlayerWebController customVideoPlayerWebController;

  Future<bool> initialize(BuildContext context) async {
    if (url == null) return false;

    if (!kIsWeb) {
      if (type == 'asset') {
        _videoPlayerController = CachedVideoPlayerController.asset(url!);
        await _videoPlayerController.initialize();
        if (autoPlay) {
          _videoPlayerController.play();
        }
      } else {
        _videoPlayerController = CachedVideoPlayerController.network(url!);
        await _videoPlayerController.initialize();
        if (autoPlay) {
          _videoPlayerController.play();
        }
      }

      customVideoPlayerController = CustomVideoPlayerController(
        context: context,
        videoPlayerController: _videoPlayerController,
        customVideoPlayerSettings: CustomVideoPlayerSettings(
          alwaysShowThumbnailOnVideoPaused: true,
          controlBarAvailable: showControlsBar,
          showFullscreenButton: allowFullScreenButton,
        ),
      );
    }

    _customVideoPlayerWebSettings = CustomVideoPlayerWebSettings(
      src: url!,
      enableControls: showControlsBar,
      autoplay: autoPlay,
    );
    customVideoPlayerWebController = CustomVideoPlayerWebController(
      webVideoPlayerSettings: _customVideoPlayerWebSettings,
    );

    return true;
  }

  void dispose() {
    if (!kIsWeb) {
      customVideoPlayerController.dispose();
      _videoPlayerController.dispose();
    }
  }
}
